==> RsSmbv-4.80.0.9-py3-none-any.whl: RsSmbv/Implementations/Source_/Bb_/Eutra_/Dl_/Subf_/Encc_/Pdcch_/DcRegs_/TrSource.py <==
from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import enums
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TrSource:
	"""TrSource commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("trSource", core, parent)

	def set(self, tran_source: enums.EutraTranSource, stream=repcap.Stream.Default) -> None:
		"""[SOURce<HW>]:BB:EUTRa:DL:[SUBF<ST>]:ENCC:PDCCh:DCRegs:TRSource \n
		Sets the behavior of the dummy REGs, i.e. determines whether dummy data or DTX is transmitted. \n
			:param tran_source: DATA| DTX
			:param stream: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Subf')"""
		param = Conversions.enum_scalar_to_str(tran_source, enums.EutraTranSource)
		stream_cmd_val = self._base.get_repcap_cmd_value(stream, repcap.Stream)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:SUBF{stream_cmd_val}:ENCC:PDCCh:DCRegs:TRSource {param}')

	# noinspection PyTypeChecker
	def get(self, stream=repcap.Stream.Default) -> enums.EutraTranSource:
		"""[SOURce<HW>]:BB:EUTRa:DL:[SUBF<ST>]:ENCC:PDCCh:DCRegs:TRSource \n
		Sets the behavior of the dummy REGs, i.e. determines whether dummy data or DTX is transmitted. \n
			:param stream: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Subf')
			:return: tran_source: DATA| DTX"""
		stream_cmd_val = self._base.get_repcap_cmd_value(stream, repcap.Stream)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:SUBF{stream_cmd_val}:ENCC:PDCCh:DCRegs:TRSource?')
		return Conversions.str_to_scalar_enum(response, enums.EutraTranSource)

==> RsSmbv-4.80.0.12-py3-none-any.whl: RsSmbv/Implementations/Source_/Bb_/Eutra_/Dl_/Subf_/Encc_/Pdcch_/DcRegs_/TrSource.py <==
from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import enums
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TrSource:
	"""TrSource commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("trSource", core, parent)

	def set(self, tran_source: enums.EutraTranSource, stream=repcap.Stream.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:[SUBF<ST>]:ENCC:PDCCh:DCRegs:TRSource \n
		Snippet: driver.source.bb.eutra.dl.subf.encc.pdcch.dcRegs.trSource.set(tran_source = enums.EutraTranSource.DATA, stream = repcap.Stream.Default) \n
		Sets the behavior of the dummy REGs, i.e. determines whether dummy data or DTX is transmitted. \n
			:param tran_source: DATA| DTX
			:param stream: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Subf')"""
		param = Conversions.enum_scalar_to_str(tran_source, enums.EutraTranSource)
		stream_cmd_val = self._base.get_repcap_cmd_value(stream, repcap.Stream)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:SUBF{stream_cmd_val}:ENCC:PDCCh:DCRegs:TRSource {param}')

	# noinspection PyTypeChecker
	def get(self, stream=repcap.Stream.Default) -> enums.EutraTranSource:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:[SUBF<ST>]:ENCC:PDCCh:DCRegs:TRSource \n
		Snippet: value: enums.EutraTranSource = driver.source.bb.eutra.dl.subf.encc.pdcch.dcRegs.trSource.get(stream = repcap.Stream.Default) \n
		Sets the behavior of the dummy REGs, i.e. determines whether dummy data or DTX is transmitted. \n
			:param stream: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Subf')
			:return: tran_source: DATA| DTX"""
		stream_cmd_val = self._base.get_repcap_cmd_value(stream, repcap.Stream)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:SUBF{stream_cmd_val}:ENCC:PDCCh:DCRegs:TRSource?')
		return Conversions.str_to_scalar_enum(response, enums.EutraTranSource)
